summaryrefslogtreecommitdiffstats
path: root/qt/qextscintillaprinter.h
diff options
context:
space:
mode:
Diffstat (limited to 'qt/qextscintillaprinter.h')
-rw-r--r--qt/qextscintillaprinter.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/qt/qextscintillaprinter.h b/qt/qextscintillaprinter.h
index 3eae387..8c0ab57 100644
--- a/qt/qextscintillaprinter.h
+++ b/qt/qextscintillaprinter.h
@@ -3,44 +3,44 @@
// Copyright (c) 2006
// Riverbank Computing Limited <info@riverbankcomputing.co.uk>
//
-// This file is part of QScintilla.
+// This file is part of TQScintilla.
//
-// This copy of QScintilla is free software; you can redistribute it and/or
+// This copy of TQScintilla is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option) any
// later version.
//
-// QScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
+// TQScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
-// QScintilla; see the file LICENSE. If not, write to the Free Software
+// TQScintilla; see the file LICENSE. If not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-#ifndef QEXTSCINTILLAPRINTER_H
-#define QEXTSCINTILLAPRINTER_H
+#ifndef TQEXTSCINTILLAPRINTER_H
+#define TQEXTSCINTILLAPRINTER_H
-#include <qprinter.h>
+#include <tqprinter.h>
-#include <qextscintillaglobal.h>
-#include <qextscintilla.h>
+#include <tqextscintillaglobal.h>
+#include <tqextscintilla.h>
-class QRect;
-class QPainter;
+class TQRect;
+class TQPainter;
class QextScintillaBase;
//! \brief The QextScintillaPrinter class is a sub-class of the Qt QPrinter
//! class that is able to print the text of a Scintilla document.
//!
-//! The class can be further sub-classed to alter to layout of the text, adding
+//! The class can be further sub-classed to alter to tqlayout of the text, adding
//! headers and footers for example.
-class QEXTSCINTILLA_EXPORT QextScintillaPrinter : public QPrinter
+class TQEXTSCINTILLA_EXPORT QextScintillaPrinter : public TQPrinter
{
public:
//! Constructs a printer paint device with mode \a mode.
@@ -58,10 +58,10 @@ public:
//! the text. This should be modified if it is necessary to reserve
//! space for any customised text or graphics. By default the area is
//! relative to the printable area of the page. Use
//! QPrinter::setFullPage() because calling printRange() if you want to
//! try and print over the whole page. \a pagenr is the number of the
//! page. The first page is numbered 1.
- virtual void formatPage(QPainter &painter,bool drawing,QRect &area,
+ virtual void formatPage(TQPainter &painter,bool drawing,TQRect &area,
int pagenr);
//! Return the number of points to add to each font when printing.
@@ -98,7 +98,7 @@ private:
int mag;
QextScintilla::WrapMode wrap;
-#if defined(Q_DISABLE_COPY)
+#if defined(TQ_DISABLE_COPY)
QextScintillaPrinter(const QextScintillaPrinter &);
QextScintillaPrinter &operator=(const QextScintillaPrinter &);
#endif
@@ -3,44 +3,44 @@
class QextScintillaBase;
-//! \brief The QextScintillaPrinter class is a sub-class of the Qt QPrinter
+//! \brief The QextScintillaPrinter class is a sub-class of the TQt TQPrinter
//! class that is able to print the text of a Scintilla document.
//!
@@ -58,10 +58,10 @@ public:
//! space for any customised text or graphics. By default the area is
//! relative to the printable area of the page. Use
- //! QPrinter::setFullPage() because calling printRange() if you want to
+ //! TQPrinter::setFullPage() because calling printRange() if you want to
//! try and print over the whole page. \a pagenr is the number of the
//! page. The first page is numbered 1.